#!/bin/bash

# set -x
set -e 

HERE=$(cd "$(dirname "${0}")" && pwd)
DEST="${HERE}/NewPackage.pkg"

if [[ $EUID -ne 0 ]]; then
   echo "This script must be run as root" 1>&2
   exit 1
fi

if [[ -d "${DEST}" ]] ; then
    echo "${DEST} already exists, exiting"
    exit 1
fi

if [[ -f "${HERE}/Contents/Archive.pax.gz"  && ! -d "${HERE}/Contents/Archive" ]] ; then
    echo "Running from inside a pkg, hence extracting Archive so that you can make changes."
    ditto -x "${HERE}/Contents/Archive.pax.gz" "${HERE}/Contents/Archive"
    find "${HERE}/Contents/Archive"
    exit 0
fi


if [[ -d "${HERE}/Contents/Archive" ]] ; then
    echo "Found an unpackaged archive, hence packaging that."
    SOURCE="${HERE}/Contents/Archive"

    chown -R root:wheel "${SOURCE}" 
    chmod -R 755 "${SOURCE}"

    if [[ ! -d "${HERE}/Contents/Resources" ]] ; then
        mkdir "${HERE}/Contents/Resources"
        echo "Welcome" > "${HERE}/Contents/Resources/Welcome.txt"
    fi

    ID="com.example.example"
    if [[ -f "${HERE}/Contents/Info.plist" ]] ; then
        ID=$(defaults read "${HERE}/Contents/Info" "CFBundleIdentifier")
    fi

    /Developer/usr/bin/packagemaker --no-recommend --target 10.4 --id ${ID} \
    -t Enabler --root "${SOURCE}" -o "${DEST}" --resources "${HERE}/Contents/Resources"

    lsbom  "${DEST}/Contents/Archive.bom"

    #defaults write "${DEST}/Contents/Info" IFPkgFlagAllowBackRev 1

    defaults read "${DEST}/Contents/Info"

    cp "${0}" "${DEST}"
    chmod -R 755 "${DEST}"
    rm -r "${DEST}"/Contents/Resources/*.lproj
    exit 0

fi

echo "Neither /Contents/Archive.pax.gz nor /Contents/Archive/ found, don't know what to do."
